faker\_file.contrib.pdf\_file package
=====================================

Submodules
----------

faker\_file.contrib.pdf\_file.pdfkit\_snippets module
-----------------------------------------------------

.. automodule:: faker_file.contrib.pdf_file.pdfkit_snippets
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.contrib.pdf\_file.reportlab\_snippets module
--------------------------------------------------------

.. automodule:: faker_file.contrib.pdf_file.reportlab_snippets
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: faker_file.contrib.pdf_file
   :members:
   :undoc-members:
   :show-inheritance:
